﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics;
using Infragistics.Controls.Charts;

namespace RealTimeStackedAreaSeriesChart
{
    using System.Windows.Threading;

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ObservableCollection<StationData> RetVal { get; set; }

        private int _i1 = 5;

        private int _i2 = 7;

        private int _i3 = 9;

        private DateTime _lastDt;

        private DispatcherTimer timer;
        protected ChartPerformanceMonitor ChartMonitor;

        public MainWindow()
        {
            InitializeComponent();
            RetVal = new ObservableCollection<StationData>();

            this.timer = new DispatcherTimer();
            this.timer.Interval = TimeSpan.FromMilliseconds(1000);
            this.timer.Tick += this.OnTimer;
            //this.timer.Start();

            //this.ChartMonitor = new ChartPerformanceMonitor();
            //this.ChartMonitor.ChartStatsChanged += OnChartMonitorStatsChanged;
            //this.ChartMonitor.DataChart = this.theChart;
            //this.ChartMonitor.StartMonitor();

        }

        private void OnChartMonitorStatsChanged(object sender, ChartPerformanceMonitor.ChartStatsChangedEventArgs e)
        {
            //var colection = this.theChart.Series[0].ItemsSource as ObservableCollection<StationData>;

            if (RetVal != null)
            {
                int totalDatapoints = this.theChart.Series.Count * RetVal.Count;
                this.DataChartUpdatesPerSecondTextBlock.Text = String.Format("{0}, Total series points = {1}", String.Format("{0:0.00}", e.ChartLayoutUpdatesPerSecond), totalDatapoints);

                using (System.IO.StreamWriter file = new System.IO.StreamWriter(@"D:\Temp\chartperformance.txt", true))
                {
                    file.WriteLine(this.DataChartUpdatesPerSecondTextBlock.Text);
                }
            }
            
        }

        private void OnTimer(object sender, EventArgs e)
        {

            //Application.Current.Dispatcher.Invoke(SimulateData);
            SimulateData();
        }

        private void SimulateData()
        {
            _i1 = new Random().Next(60, 300);
            _i2 = new Random().Next(50, 250);
            _i3 = new Random().Next(10, 250);

            DateTime dt = DateTime.Now;

            RetVal.Add(new StationData("A", _i1, dt));
            RetVal.Add(new StationData("B", _i2, dt));
            RetVal.Add(new StationData("C", _i3, dt));
        }
        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            GroupBy gb = new GroupBy();

            gb.GroupMemberPath = "DateStamp";
            gb.KeyMemberPath = "Station";
            gb.ValueMemberPath = "Pressure";

            RetVal = StationDataCollection.GetItemSource();
            gb.ItemsSource = RetVal;

            Infragistics.Controls.Charts.NumericYAxis yAxis = new NumericYAxis();

            CategoryXAxis xAxis = new CategoryXAxis();
            xAxis.ItemsSource = gb;
            // xAxis.Label = Resources["labels"] as DataTemplate;
            xAxis.Label = "{Key}";
            this.theChart.Axes.Add(xAxis);
            this.theChart.Axes.Add(yAxis);

            StackedAreaSeries series = new StackedAreaSeries();

            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.ItemsSource = gb;
            series.AutoGenerateSeries = true;
            theChart.Series.Add(series);
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //_i1 += 2;
            //_i2 += 2;
            //_i3 += 2;
            //DateTime dt = DateTime.Now;
            //RetVal.Add(new StationData("A", _i1, dt ));
            //RetVal.Add(new StationData("B", _i2, dt ));
            //RetVal.Add(new StationData("C", _i3, dt ));

             this.timer.Start();
        }

        private void Button2_Click(object sender, RoutedEventArgs e)
        {
             this.timer.Stop();
        }
    }

    public class StationDataCollection
    {

        public static ObservableCollection<StationData> GetItemSource()
        {

            DateTime dt = DateTime.Now;

            ObservableCollection<StationData> retVal = new ObservableCollection<StationData>();

            retVal.Add(new StationData("A", 5, dt.AddMinutes(-2)));
            retVal.Add(new StationData("B", 2, dt.AddMinutes(-1)));
            retVal.Add(new StationData("C", 7, dt));

            retVal.Add(new StationData("A", 6, dt.AddMinutes(-2)));
            retVal.Add(new StationData("B", 3, dt.AddMinutes(-1)));
            retVal.Add(new StationData("C", 8, dt));

            retVal.Add(new StationData("A", 6, dt.AddMinutes(-2)));
            retVal.Add(new StationData("B", 3, dt.AddMinutes(-1)));
            retVal.Add(new StationData("C", 6, dt));

            //retVal.Add(new StationData("A", 4, dt.AddMinutes(-2)));
            //retVal.Add(new StationData("B", 3, dt.AddMinutes(-1)));
            //retVal.Add(new StationData("C", 7, dt));

            //retVal.Add(new StationData("D", 7, "1/1/2012", 1));
            //retVal.Add(new StationData("D", 8, "1/2/2012", 1));
            //retVal.Add(new StationData("D", 6, "1/3/2012", 1));
            //retVal.Add(new StationData("D", 7, "1/4/2012", 1));

            

            return retVal;
        }

        
    }

    public class StationData
    {
        public string Station { get; set; }
        public double Pressure { get; set; }
        public DateTime DateStamp { get; set; }

        public StationData(string installation, double pressure, DateTime date)
        {
            Station = installation;
            Pressure = pressure;
            DateStamp = date;
        }
    }
}